@@ -1,5 +1,8 @@
 import json
-from typing import Dict
+import os.path
+from typing import Dict, Callable
+
+from assertpy import assert_that
 
 from deepdriver.sdk.artifact import Artifacts, ArtifactEntry
 from deepdriver.sdk.data_types.run import get_run
@@ -46,6 +49,32 @@ def get_artifact(name: str, type: str, tag: str="", team_name: str="", exp_name:
         entry_list=entry_list,
     )
 
+
+@util.login_required
+@util.init_required
+def upload_code(name: str = None, type: str = "CODE", tag: str = "", team_name: str = None, exp_name: str = None,
+                path: str = "./", include_func: Callable = lambda path: path.endswith("py") or path.endswith("ipynb"), exclude_func: Callable = lambda path: False) -> None:
+    assert_that(name).is_not_none()
+    assert_that(path).is_not_none()
+
+    if not team_name :
+        team_name = get_run().team_name
+    if not exp_name:
+        exp_name = get_run().exp_name
+
+    arti = get_artifact(name=name, type=type, tag=tag, team_name=team_name, exp_name=exp_name)
+
+    import glob
+    for file_path in glob.glob(os.path.join(path, "**"), recursive=True):
+        if os.path.isdir(file_path):
+            continue
+        if include_func(file_path) and (not exclude_func(file_path)):
+            logger.debug(f"path added: {file_path}")
+            arti.add(file_path)
+    arti.upload()
+    pass
+
+
 # Interface.py의 finish()함수를 호출할때 하기의 summary정보를 dictionary 형태로 넘겨준다
 @util.init_required
 def finish() -> bool:
